# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SPHERE_METADATA = Metadata(
    id="ff70a8889110348344f49593918baf25bab92371.boutiques",
    name="mris_sphere",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_sphere(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_patch_file: OutputPathType
    """Output patch file."""


def mris_sphere(
    surface_file: InputPathType,
    patch_file: InputPathType,
    output_patch: str,
    runner: Runner | None = None,
) -> MrisSphereOutputs:
    """
    This program will add a template into an average surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface_file: Input surface file.
        patch_file: Input patch file name.
        output_patch: Output patch file name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SPHERE_METADATA)
    cargs = []
    cargs.append("mris_sphere")
    cargs.append(execution.input_file(surface_file))
    cargs.append(execution.input_file(patch_file))
    cargs.append(output_patch)
    ret = MrisSphereOutputs(
        root=execution.output_file("."),
        output_patch_file=execution.output_file(output_patch),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SPHERE_METADATA",
    "MrisSphereOutputs",
    "mris_sphere",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MYGET_METADATA = Metadata(
    id="2f6d3f9ad29fa84e230f411a821134ff68c91853.boutiques",
    name="myget",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MygetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `myget(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The filename to save the downloaded file"""


def myget(
    url: str,
    protocol_version: typing.Literal["-1", "-1.1"] | None = None,
    runner: Runner | None = None,
) -> MygetOutputs:
    """
    A simple file downloader from a URL.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        url: The URL to download the file from.
        protocol_version: Specify protocol version. You can choose between -1\
            or -1.1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MygetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MYGET_METADATA)
    cargs = []
    if protocol_version is not None:
        cargs.append("myget" + protocol_version + url)
    ret = MygetOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MYGET_METADATA",
    "MygetOutputs",
    "myget",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RANKIZER_METADATA = Metadata(
    id="e854a99a853a99ed471d7da08fb007bec90426d2.boutiques",
    name="3dRankizer",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRankizerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_rankizer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output float-format dataset containing ranked voxel values"""


def v_3d_rankizer(
    dataset: InputPathType,
    prefix: str,
    base_rank: float | None = None,
    mask: InputPathType | None = None,
    percentize: bool = False,
    percentize_mask: bool = False,
    runner: Runner | None = None,
) -> V3dRankizerOutputs:
    """
    Tool to rank each voxel as sorted into increasing value. Ties get the average
    rank.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input MRI dataset.
        prefix: Write results into float-format output dataset.
        base_rank: Set the 'base' rank instead of 1.
        mask: Use the specified dataset as a mask. Only voxels with nonzero\
            values in this mask will be used from the input dataset. Voxels outside\
            the mask will get rank 0.
        percentize: Divide rank by the number of voxels in the dataset and\
            multiply by 100.0.
        percentize_mask: Divide rank by the number of voxels in the mask and\
            multiply by 100.0.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRankizerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RANKIZER_METADATA)
    cargs = []
    cargs.append("3dRankizer")
    cargs.append(execution.input_file(dataset))
    if base_rank is not None:
        cargs.extend([
            "-brank",
            str(base_rank)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if percentize:
        cargs.append("-percentize")
    if percentize_mask:
        cargs.append("-percentize_mask")
    ret = V3dRankizerOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + "+tlrc.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRankizerOutputs",
    "V_3D_RANKIZER_METADATA",
    "v_3d_rankizer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MKSUBJDIRS_METADATA = Metadata(
    id="19b08b172da5b6336a32dd0488cf331beb47bbc0.boutiques",
    name="mksubjdirs",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MksubjdirsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mksubjdirs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mksubjdirs(
    subj_name: str,
    mode: str | None = None,
    parents: bool = False,
    verbose: bool = False,
    selinux_context: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MksubjdirsOutputs:
    """
    A command-line tool to create subject directories.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subj_name: Name of the subject directory to create.
        mode: Set file mode (as in chmod), not a=rwx - umask.
        parents: No error if existing, make parent directories as needed.
        verbose: Print a message for each created directory.
        selinux_context: Set SELinux security context of each created directory\
            to the default type.
        help_: Display help and exit.
        version: Output version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MksubjdirsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MKSUBJDIRS_METADATA)
    cargs = []
    cargs.append("mksubjdirs")
    cargs.append(subj_name)
    if mode is not None:
        cargs.extend([
            "-m",
            mode
        ])
    if parents:
        cargs.append("-p")
    if verbose:
        cargs.append("-v")
    if selinux_context:
        cargs.append("-Z")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MksubjdirsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MKSUBJDIRS_METADATA",
    "MksubjdirsOutputs",
    "mksubjdirs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MI_METADATA = Metadata(
    id="a8192108178632d862688e0dfe4e9538ca88d9ad.boutiques",
    name="mri_mi",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_mi(
    input_file1: InputPathType,
    input_file2: InputPathType,
    bins: str | None = None,
    silent: bool = False,
    runner: Runner | None = None,
) -> MriMiOutputs:
    """
    Computes mutual information (mi) between two input volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file1: First input file name.
        input_file2: Second input file name.
        bins: Specifies the number of bins for the two input volumes. Default\
            is 64x64.
        silent: Write out only the final mutual information result.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MI_METADATA)
    cargs = []
    cargs.append("mri_mi")
    cargs.append(execution.input_file(input_file1))
    cargs.append(execution.input_file(input_file2))
    if bins is not None:
        cargs.extend([
            "--bins",
            bins
        ])
    if silent:
        cargs.append("--silent")
    ret = MriMiOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MI_METADATA",
    "MriMiOutputs",
    "mri_mi",
]



"""
dcm2niix

Chris Rorden's dcm2niiX - DICOM to NIfTI converter. Converts DICOM files to
NIfTI format with optional BIDS sidecar generation.

URL: https://github.com/rordenlab/dcm2niix
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .dcm2niix import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PLUGOUT_IJK_METADATA = Metadata(
    id="546af73f34fcb7f296f73da1cc63ae4ec231fec2.boutiques",
    name="plugout_ijk",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PlugoutIjkOutputs(typing.NamedTuple):
    """
    Output object returned when calling `plugout_ijk(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def plugout_ijk(
    host: str | None = None,
    verbose: bool = False,
    port: float | None = None,
    name: str | None = None,
    port_offset: float | None = None,
    port_quiet: float | None = None,
    port_bloc_offset: float | None = None,
    max_bloc: bool = False,
    max_bloc_quiet: bool = False,
    num_assigned_ports: bool = False,
    num_assigned_ports_quiet: bool = False,
    runner: Runner | None = None,
) -> PlugoutIjkOutputs:
    """
    Connects to AFNI and sends (i,j,k) dataset indices to control the viewpoint.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        host: Connect to AFNI running on the specified computer using TCP/IP.
        verbose: Verbose mode.
        port: Use TCP/IP port number 'pp'.
        name: Use the string 'sss' for the name that AFNI assigns to this\
            plugout.
        port_offset: Provide a port offset to allow multiple instances of\
            communicating programs to operate on the same machine.
        port_quiet: Provide a port offset like -np, but more quiet in the face\
            of adversity.
        port_bloc_offset: Provide a port offset block for easier port\
            management.
        max_bloc: Print the current value of MAX_BLOC and exit.
        max_bloc_quiet: Print MAX_BLOC value only and exit.
        num_assigned_ports: Print the number of assigned ports used by AFNI\
            then quit.
        num_assigned_ports_quiet: Prints the number of assigned ports quietly.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PlugoutIjkOutputs`).
    """
    if port_offset is not None and not (1025 <= port_offset <= 65500): 
        raise ValueError(f"'port_offset' must be between 1025 <= x <= 65500 but was {port_offset}")
    if port_bloc_offset is not None and not (port_bloc_offset <= 4000): 
        raise ValueError(f"'port_bloc_offset' must be less than x <= 4000 but was {port_bloc_offset}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(PLUGOUT_IJK_METADATA)
    cargs = []
    cargs.append("plugout_ijk")
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if verbose:
        cargs.append("-v")
    if port is not None:
        cargs.extend([
            "-port",
            str(port)
        ])
    if name is not None:
        cargs.extend([
            "-name",
            name
        ])
    if port_offset is not None:
        cargs.extend([
            "-np",
            str(port_offset)
        ])
    if port_quiet is not None:
        cargs.extend([
            "-npq",
            str(port_quiet)
        ])
    if port_bloc_offset is not None:
        cargs.extend([
            "-npb",
            str(port_bloc_offset)
        ])
    if max_bloc:
        cargs.append("-max_port_bloc")
    if max_bloc_quiet:
        cargs.append("-max_port_bloc_quiet")
    if num_assigned_ports:
        cargs.append("-num_assigned_ports")
    if num_assigned_ports_quiet:
        cargs.append("-num_assigned_ports_quiet")
    ret = PlugoutIjkOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PLUGOUT_IJK_METADATA",
    "PlugoutIjkOutputs",
    "plugout_ijk",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIX_SUBJECT_RH_METADATA = Metadata(
    id="3bb32adfbfd21f826f4e479a088d3bcfcdad5042.boutiques",
    name="fix_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FixSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fix_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fix_subject_rh(
    input_directory: str,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> FixSubjectRhOutputs:
    """
    A tool from FreeSurfer that performs operations on the right hemisphere data
    within a specified directory.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_directory: Directory where the subject's right hemisphere data is\
            located.
        help_flag: Displays help information for fix_subject-rh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIX_SUBJECT_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "fix_subject" + input_directory
    ])
    if help_flag:
        cargs.append("--help")
    ret = FixSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIX_SUBJECT_RH_METADATA",
    "FixSubjectRhOutputs",
    "fix_subject_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_NEUROIMAGING_BATTERY_METADATA = Metadata(
    id="8d5f7d9ec665c8a4728e1d76b9ae72be2a9a3489.boutiques",
    name="antsNeuroimagingBattery",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsNeuroimagingBatteryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_neuroimaging_battery(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform: OutputPathType
    """Output transform files."""


def ants_neuroimaging_battery(
    input_directory: str,
    output_directory: str,
    output_name: str,
    anatomical_image: InputPathType,
    anatomical_mask: InputPathType,
    runner: Runner | None = None,
) -> AntsNeuroimagingBatteryOutputs:
    """
    Align MR modalities to a common within-subject (and optional template) space.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_directory: Directory where to look for modality images.
        output_directory: Directory where output goes (where\
            antsCorticalThickness output lives).
        output_name: File prefix for outputs.
        anatomical_image: Reference subject image (usually T1).
        anatomical_mask: Mask of anatomical image, should contain cerebrum,\
            cerebellum, and brainstem.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsNeuroimagingBatteryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_NEUROIMAGING_BATTERY_METADATA)
    cargs = []
    cargs.append("antsNeuroimagingBattery.pl")
    cargs.extend([
        "--input-directory",
        input_directory
    ])
    cargs.extend([
        "--output-directory",
        output_directory
    ])
    cargs.extend([
        "--output-name",
        output_name
    ])
    cargs.extend([
        "--anatomical",
        execution.input_file(anatomical_image)
    ])
    cargs.extend([
        "--anatomical-mask",
        execution.input_file(anatomical_mask)
    ])
    cargs.append("[OPTIONAL_INPUTS]")
    ret = AntsNeuroimagingBatteryOutputs(
        root=execution.output_file("."),
        output_transform=execution.output_file(output_directory + "/" + output_name + ".*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_NEUROIMAGING_BATTERY_METADATA",
    "AntsNeuroimagingBatteryOutputs",
    "ants_neuroimaging_battery",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIDUCIALS_CALIBRATION_METADATA = Metadata(
    id="445a4b2fe29e36b5286fe1c80268453941ab7144.boutiques",
    name="fiducials_calibration",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FiducialsCalibrationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fiducials_calibration(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fiducials_calibration(
    runner: Runner | None = None,
) -> FiducialsCalibrationOutputs:
    """
    A tool used for calibrating fiducials.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FiducialsCalibrationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIDUCIALS_CALIBRATION_METADATA)
    cargs = []
    cargs.append("fiducials_calibration")
    ret = FiducialsCalibrationOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIDUCIALS_CALIBRATION_METADATA",
    "FiducialsCalibrationOutputs",
    "fiducials_calibration",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IFH2HDR_METADATA = Metadata(
    id="e59ad437a43879fdeda8a194eb2d5e26f853b35c.boutiques",
    name="ifh2hdr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Ifh2hdrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ifh2hdr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def ifh2hdr(
    input_file: InputPathType,
    range_: str | None = None,
    runner: Runner | None = None,
) -> Ifh2hdrOutputs:
    """
    Tool for converting IFH (Interfile Header) to HDR (Header) format in 4dfp
    (Four-Dimensional Functional Image) file format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input 4dfp file.
        range_: Set range for the 4dfp file. Format: <float>[to<float>].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Ifh2hdrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IFH2HDR_METADATA)
    cargs = []
    cargs.append("ifh2hdr")
    cargs.append(execution.input_file(input_file))
    if range_ is not None:
        cargs.extend([
            "-r",
            range_
        ])
    ret = Ifh2hdrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IFH2HDR_METADATA",
    "Ifh2hdrOutputs",
    "ifh2hdr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_EXTREMA_METADATA = Metadata(
    id="eb5e28d060e46506bf7d2f474eaa01ce1fdbeac0.boutiques",
    name="cifti-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiExtremaThreshold:
    """
    ignore small extrema.
    """
    low: float
    """the largest value to consider for being a minimum"""
    high: float
    """the smallest value to consider for being a maximum"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-threshold")
        cargs.append(str(self.low))
        cargs.append(str(self.high))
        return cargs


class CiftiExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_extrema(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_extrema(
    cifti: InputPathType,
    surface_distance: float,
    volume_distance: float,
    direction: str,
    cifti_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    opt_surface_presmooth_surface_kernel: float | None = None,
    opt_volume_presmooth_volume_kernel: float | None = None,
    opt_presmooth_fwhm: bool = False,
    threshold: CiftiExtremaThreshold | None = None,
    opt_merged_volume: bool = False,
    opt_sum_maps: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
    runner: Runner | None = None,
) -> CiftiExtremaOutputs:
    """
    Find extrema in a cifti file.
    
    Finds spatial locations in a cifti file that have more extreme values than
    all nearby locations in the same component (surface or volume structure).
    The input cifti file must have a brain models mapping along the specified
    direction. COLUMN is the direction that works on dtseries and dscalar. For
    dconn, if it is symmetric use COLUMN, otherwise use ROW.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti.
        surface_distance: the minimum distance between extrema of the same\
            type, for surface components.
        volume_distance: the minimum distance between extrema of the same type,\
            for volume components.
        direction: which dimension to find extrema along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        opt_surface_presmooth_surface_kernel: smooth on the surface before\
            finding extrema: the size of the gaussian surface smoothing kernel in\
            mm, as sigma by default.
        opt_volume_presmooth_volume_kernel: smooth volume components before\
            finding extrema: the size of the gaussian volume smoothing kernel in\
            mm, as sigma by default.
        opt_presmooth_fwhm: smoothing kernel distances are FWHM, not sigma.
        threshold: ignore small extrema.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        opt_sum_maps: output the sum of the extrema maps instead of each map\
            separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_EXTREMA_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-extrema")
    cargs.append(execution.input_file(cifti))
    cargs.append(str(surface_distance))
    cargs.append(str(volume_distance))
    cargs.append(direction)
    cargs.append(cifti_out)
    if opt_left_surface_surface is not None:
        cargs.extend([
            "-left-surface",
            execution.input_file(opt_left_surface_surface)
        ])
    if opt_right_surface_surface is not None:
        cargs.extend([
            "-right-surface",
            execution.input_file(opt_right_surface_surface)
        ])
    if opt_cerebellum_surface_surface is not None:
        cargs.extend([
            "-cerebellum-surface",
            execution.input_file(opt_cerebellum_surface_surface)
        ])
    if opt_surface_presmooth_surface_kernel is not None:
        cargs.extend([
            "-surface-presmooth",
            str(opt_surface_presmooth_surface_kernel)
        ])
    if opt_volume_presmooth_volume_kernel is not None:
        cargs.extend([
            "-volume-presmooth",
            str(opt_volume_presmooth_volume_kernel)
        ])
    if opt_presmooth_fwhm:
        cargs.append("-presmooth-fwhm")
    if threshold is not None:
        cargs.extend(threshold.run(execution))
    if opt_merged_volume:
        cargs.append("-merged-volume")
    if opt_sum_maps:
        cargs.append("-sum-maps")
    if opt_consolidate_mode:
        cargs.append("-consolidate-mode")
    if opt_only_maxima:
        cargs.append("-only-maxima")
    if opt_only_minima:
        cargs.append("-only-minima")
    ret = CiftiExtremaOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_EXTREMA_METADATA",
    "CiftiExtremaOutputs",
    "CiftiExtremaThreshold",
    "cifti_extrema",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_STATS2SEG_METADATA = Metadata(
    id="a4b8c39c09b61ee54a4a039bc3c05dcc8e51531c.boutiques",
    name="mri_stats2seg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriStats2segOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_stats2seg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmented_output: OutputPathType
    """Output segmented file."""


def mri_stats2seg(
    stat_file: InputPathType,
    segmentation_volume: InputPathType,
    output_file: str,
    debug: bool = False,
    check_opts: bool = False,
    runner: Runner | None = None,
) -> MriStats2segOutputs:
    """
    A command-line tool for converting MRI statistical maps to segmented volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        stat_file: Stat file in an MRI format.
        segmentation_volume: Segmentation volume file.
        output_file: Output file.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriStats2segOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_STATS2SEG_METADATA)
    cargs = []
    cargs.append("mri_stats2seg")
    cargs.extend([
        "--stat",
        execution.input_file(stat_file)
    ])
    cargs.extend([
        "--seg",
        execution.input_file(segmentation_volume)
    ])
    cargs.extend([
        "--o",
        output_file
    ])
    if debug:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    ret = MriStats2segOutputs(
        root=execution.output_file("."),
        segmented_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_STATS2SEG_METADATA",
    "MriStats2segOutputs",
    "mri_stats2seg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BLUR_TO_FWHM_METADATA = Metadata(
    id="f4b40fc76ce4b806bbbbfa509356f57bb656233d.boutiques",
    name="3dBlurToFWHM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBlurToFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_blur_to_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Output image file name."""


def v_3d_blur_to_fwhm(
    in_file: InputPathType,
    automask: bool = False,
    blurmaster: InputPathType | None = None,
    fwhm: float | None = None,
    fwhmxy: float | None = None,
    mask: InputPathType | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dBlurToFwhmOutputs:
    """
    Blurs a 'master' dataset until it reaches a specified FWHM smoothness
    (approximately).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: The dataset that will be smoothed.
        automask: Create an automask from the input dataset.
        blurmaster: The dataset whose smoothness controls the process.
        fwhm: Blur until the 3d fwhm reaches this value (in mm).
        fwhmxy: Blur until the 2d (x,y)-plane fwhm reaches this value (in mm).
        mask: Mask dataset, if desired. voxels not in mask will be set to zero\
            in output.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        prefix: Prefix for output dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBlurToFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BLUR_TO_FWHM_METADATA)
    cargs = []
    cargs.append("3dBlurToFWHM")
    if automask:
        cargs.append("-automask")
    if blurmaster is not None:
        cargs.extend([
            "-blurmaster",
            execution.input_file(blurmaster)
        ])
    if fwhm is not None:
        cargs.extend([
            "-FWHM",
            str(fwhm)
        ])
    if fwhmxy is not None:
        cargs.extend([
            "-FWHMxy",
            str(fwhmxy)
        ])
    cargs.extend([
        "-input",
        execution.input_file(in_file)
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if outputtype is not None:
        cargs.append(outputtype)
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    ret = V3dBlurToFwhmOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBlurToFwhmOutputs",
    "V_3D_BLUR_TO_FWHM_METADATA",
    "v_3d_blur_to_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_MATCH_METADATA = Metadata(
    id="efe736f14c6cc3e4977733f00b21400160482da4.boutiques",
    name="dmri_match",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriMatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_match(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file from dmri_match"""


def dmri_match(
    parcellation1: InputPathType,
    parcellation2: InputPathType,
    num_clusters: float,
    clustering_path1: InputPathType,
    clustering_path2: InputPathType,
    output: str,
    labels: bool = False,
    euclidean: bool = False,
    bounding_box: bool = False,
    symmetry: bool = False,
    inter_hemi_ratio_removal: str | None = None,
    runner: Runner | None = None,
) -> DmriMatchOutputs:
    """
    Tool for matching diffusion MRI parcellations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        parcellation1: First parcellation input file.
        parcellation2: Second parcellation input file.
        num_clusters: Number of clusters.
        clustering_path1: First clustering path.
        clustering_path2: Second clustering path.
        output: Output file.
        labels: Use labels (no additional input expected).
        euclidean: Use Euclidean distance for matching.
        bounding_box: Use bounding box constraint (no additional input\
            expected).
        symmetry: Use symmetry constraint (no additional input expected).
        inter_hemi_ratio_removal: Inter-hemispheric ratio cluster removal\
            constraint.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriMatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_MATCH_METADATA)
    cargs = []
    cargs.append("dmri_match")
    cargs.extend([
        "-s1",
        execution.input_file(parcellation1)
    ])
    cargs.extend([
        "-s2",
        execution.input_file(parcellation2)
    ])
    cargs.extend([
        "-c",
        str(num_clusters)
    ])
    cargs.extend([
        "-h1",
        execution.input_file(clustering_path1)
    ])
    cargs.extend([
        "-h2",
        execution.input_file(clustering_path2)
    ])
    if labels:
        cargs.append("-labels")
    if euclidean:
        cargs.append("-euclid")
    if bounding_box:
        cargs.append("-bb")
    if symmetry:
        cargs.append("-sym")
    if inter_hemi_ratio_removal is not None:
        cargs.append(inter_hemi_ratio_removal)
    cargs.extend([
        "-o",
        output
    ])
    ret = DmriMatchOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_MATCH_METADATA",
    "DmriMatchOutputs",
    "dmri_match",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_FIX_TEXT_METADATA = Metadata(
    id="a220cb697a269f6545c026e4c1c455f141351c48.boutiques",
    name="fslFixText",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslFixTextOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_fix_text(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_text_file: OutputPathType
    """Output text file with standard UNIX line endings"""


def fsl_fix_text(
    input_text_file: InputPathType,
    output_text_file: str,
    runner: Runner | None = None,
) -> FslFixTextOutputs:
    """
    Ensures standard UNIX line endings in the output text file.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_text_file: Input text file.
        output_text_file: Output text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslFixTextOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_FIX_TEXT_METADATA)
    cargs = []
    cargs.append("fslFixText")
    cargs.append(execution.input_file(input_text_file))
    cargs.append(output_text_file)
    ret = FslFixTextOutputs(
        root=execution.output_file("."),
        output_text_file=execution.output_file(output_text_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_FIX_TEXT_METADATA",
    "FslFixTextOutputs",
    "fsl_fix_text",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIX_SUBJECT_CORRECTED_RH_METADATA = Metadata(
    id="52da465b947b94728415b771545cea34c0073071.boutiques",
    name="fix_subject_corrected-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FixSubjectCorrectedRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fix_subject_corrected_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    log_file: OutputPathType
    """Log file generated during the execution"""


def fix_subject_corrected_rh(
    subject_dir: str,
    runner: Runner | None = None,
) -> FixSubjectCorrectedRhOutputs:
    """
    A tool related to FreeSurfer subject correction.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Path to the FreeSurfer subject directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixSubjectCorrectedRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIX_SUBJECT_CORRECTED_RH_METADATA)
    cargs = []
    cargs.extend([
        "-rh",
        "fix_subject_corrected" + subject_dir
    ])
    ret = FixSubjectCorrectedRhOutputs(
        root=execution.output_file("."),
        log_file=execution.output_file(subject_dir + "/scripts_output.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIX_SUBJECT_CORRECTED_RH_METADATA",
    "FixSubjectCorrectedRhOutputs",
    "fix_subject_corrected_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MAKE_FACE_PARCELLATION_METADATA = Metadata(
    id="47813723c3b8dcdc56ee88729e050b27cbb7ae13.boutiques",
    name="mris_make_face_parcellation",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMakeFaceParcellationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_make_face_parcellation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    annot_file: OutputPathType
    """Generated annotation file based on the icosahedral face mapping."""


def mris_make_face_parcellation(
    input_surface: InputPathType,
    ico_file: InputPathType,
    output_annot: str,
    colortable: InputPathType | None = None,
    runner: Runner | None = None,
) -> MrisMakeFaceParcellationOutputs:
    """
    Generates a parcellation based on which icosahedral face each vertex maps to.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file (e.g. lh.sphere or lh.sphere.reg).
        ico_file: Icosahedron file (e.g. ic3.tri).
        output_annot: Output annotation file (e.g. lh.ic3.annot).
        colortable: Color table file (e.g. colortable.txt).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMakeFaceParcellationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MAKE_FACE_PARCELLATION_METADATA)
    cargs = []
    cargs.append("mris_make_face_parcellation")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(ico_file))
    cargs.append(output_annot)
    if colortable is not None:
        cargs.extend([
            "-ctab",
            execution.input_file(colortable)
        ])
    ret = MrisMakeFaceParcellationOutputs(
        root=execution.output_file("."),
        annot_file=execution.output_file(output_annot),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MAKE_FACE_PARCELLATION_METADATA",
    "MrisMakeFaceParcellationOutputs",
    "mris_make_face_parcellation",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF2VOL_METADATA = Metadata(
    id="f4ae5ac678a739e2426d3a890649ef1fbff288ef.boutiques",
    name="surf2vol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Surf2volOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf2vol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Default output of the deformation process."""
    output_field: OutputPathType | None
    """Field output of the deformation process."""


def surf2vol(
    fixed_surface: InputPathType,
    moving_surface: InputPathType,
    fixed_mri: InputPathType,
    moving_mri: InputPathType,
    output_file: str | None = "out.mgz",
    output_field: str | None = "out_field.mgz",
    output_affine: str | None = None,
    output_surf: str | None = None,
    output_surf_affine: str | None = None,
    output_mesh: str | None = None,
    spacing_x: float | None = None,
    spacing_y: float | None = None,
    spacing_z: float | None = None,
    poisson_ratio: float | None = None,
    dirty_factor: float | None = None,
    debug_output: bool = False,
    cache_transform: str | None = None,
    runner: Runner | None = None,
) -> Surf2volOutputs:
    """
    Diffuse surface deformation to volumes using surface and MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        fixed_surface: File path for the main fixed surface.
        moving_surface: File path for the main moving surface.
        fixed_mri: Fixed volume file.
        moving_mri: Moving volume file.
        output_file: Output file for the result, default is out.mgz.
        output_field: Output field file, default is out_field.mgz.
        output_affine: Path for the output affine file.
        output_surf: Root file name for output surfaces which will have indices\
            appended for each surface.
        output_surf_affine: Root file name for output surfaces with affine\
            transformations.
        output_mesh: File path for the output mesh.
        spacing_x: Specifies the x spacing for the deformation grid.
        spacing_y: Specifies the y spacing for the deformation grid.
        spacing_z: Specifies the z spacing for the deformation grid.
        poisson_ratio: Poisson ratio for material properties, default is 0.3.
        dirty_factor: Factor for dirty regions, between 0 and 1.
        debug_output: Enable debug output, writing a morph file at each\
            iteration.
        cache_transform: Path to save transformation cache for reusing in\
            subsequent runs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Surf2volOutputs`).
    """
    if poisson_ratio is not None and not (poisson_ratio <= 0.5): 
        raise ValueError(f"'poisson_ratio' must be less than x <= 0.5 but was {poisson_ratio}")
    if dirty_factor is not None and not (0 <= dirty_factor <= 1): 
        raise ValueError(f"'dirty_factor' must be between 0 <= x <= 1 but was {dirty_factor}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF2VOL_METADATA)
    cargs = []
    cargs.append("surf2vol")
    cargs.extend([
        "-fixed_surf",
        execution.input_file(fixed_surface)
    ])
    cargs.extend([
        "-moving_surf",
        execution.input_file(moving_surface)
    ])
    cargs.extend([
        "-fixed_mri",
        execution.input_file(fixed_mri)
    ])
    cargs.extend([
        "-moving_mri",
        execution.input_file(moving_mri)
    ])
    if output_file is not None:
        cargs.extend([
            "-out",
            output_file
        ])
    if output_field is not None:
        cargs.extend([
            "-out_field",
            output_field
        ])
    if output_affine is not None:
        cargs.extend([
            "-out_affine",
            output_affine
        ])
    if output_surf is not None:
        cargs.extend([
            "-out_surf",
            output_surf
        ])
    if output_surf_affine is not None:
        cargs.extend([
            "-out_surf_affine",
            output_surf_affine
        ])
    if output_mesh is not None:
        cargs.extend([
            "-out_mesh",
            output_mesh
        ])
    if spacing_x is not None:
        cargs.extend([
            "-spacing_x",
            str(spacing_x)
        ])
    if spacing_y is not None:
        cargs.extend([
            "-spacing_y",
            str(spacing_y)
        ])
    if spacing_z is not None:
        cargs.extend([
            "-spacing_z",
            str(spacing_z)
        ])
    if poisson_ratio is not None:
        cargs.extend([
            "-poisson",
            str(poisson_ratio)
        ])
    if dirty_factor is not None:
        cargs.extend([
            "-dirty",
            str(dirty_factor)
        ])
    if debug_output:
        cargs.append("-dbg_output")
    if cache_transform is not None:
        cargs.extend([
            "-cache_transform",
            cache_transform
        ])
    ret = Surf2volOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file) if (output_file is not None) else None,
        output_field=execution.output_file(output_field) if (output_field is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF2VOL_METADATA",
    "Surf2volOutputs",
    "surf2vol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_WILCOXON_METADATA = Metadata(
    id="463bd0c7f172cd1b8be0a6f1adaeefb51a0010ea.boutiques",
    name="3dWilcoxon",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dWilcoxonOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_wilcoxon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Estimated population delta and Wilcoxon signed-rank statistics"""


def v_3d_wilcoxon(
    dset1_x: list[InputPathType],
    dset2_y: list[InputPathType],
    output_prefix: str,
    workmem: float | None = None,
    voxel: float | None = None,
    runner: Runner | None = None,
) -> V3dWilcoxonOutputs:
    """
    Nonparametric Wilcoxon signed-rank test for paired comparisons of two samples.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dset1_x: Data set for X observations. The user must specify 1 and only\
            1 sub-brick with each -dset command.
        dset2_y: Data set for Y observations. The user must specify 1 and only\
            1 sub-brick with each -dset command.
        output_prefix: Estimated population delta and Wilcoxon signed-rank\
            statistics are written to file.
        workmem: Number of megabytes of RAM to use for statistical workspace.
        voxel: Screen output for voxel # num.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dWilcoxonOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_WILCOXON_METADATA)
    cargs = []
    cargs.append("3dWilcoxon")
    if workmem is not None:
        cargs.extend([
            "-workmem",
            str(workmem)
        ])
    if voxel is not None:
        cargs.extend([
            "-voxel",
            str(voxel)
        ])
    cargs.append("-dset")
    cargs.append("1")
    cargs.extend([execution.input_file(f) for f in dset1_x])
    cargs.append("-dset")
    cargs.append("2")
    cargs.extend([execution.input_file(f) for f in dset2_y])
    cargs.extend([
        "-out",
        output_prefix
    ])
    ret = V3dWilcoxonOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dWilcoxonOutputs",
    "V_3D_WILCOXON_METADATA",
    "v_3d_wilcoxon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EXTRACT_METADATA = Metadata(
    id="8ea8492114a69493e6fb6d2e1d9f2b2b63d51237.boutiques",
    name="mri_extract",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriExtractOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_extract(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_extracted_volume: OutputPathType
    """Output file with extracted MRI data."""


def mri_extract(
    src_volume: InputPathType,
    dst_volume: InputPathType,
    like_template: InputPathType | None = None,
    coordinates: list[float] | None = None,
    runner: Runner | None = None,
) -> MriExtractOutputs:
    """
    MRI data extraction tool for FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_volume: Source MRI volume file from which data will be extracted.
        dst_volume: The destination file where the extracted data will be\
            saved.
        like_template: Extract region like the given template volume.
        coordinates: Coordinates and size of the extraction box: x0 y0 z0 dx dy\
            dz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriExtractOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EXTRACT_METADATA)
    cargs = []
    cargs.append("mri_extract")
    if like_template is not None:
        cargs.extend([
            "-like",
            execution.input_file(like_template)
        ])
    cargs.append(execution.input_file(src_volume))
    cargs.append(execution.input_file(dst_volume))
    if coordinates is not None:
        cargs.extend(map(str, coordinates))
    ret = MriExtractOutputs(
        root=execution.output_file("."),
        output_extracted_volume=execution.output_file(pathlib.Path(dst_volume).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EXTRACT_METADATA",
    "MriExtractOutputs",
    "mri_extract",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RCA_BASE_INIT_METADATA = Metadata(
    id="40035e4c6889519a8062b007d6e932c3e18ff078.boutiques",
    name="rca-base-init",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RcaBaseInitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rca_base_init(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rca_base_init(
    log_file: str | None = None,
    status_file: str | None = None,
    cmd_file: str | None = None,
    runner: Runner | None = None,
) -> RcaBaseInitOutputs:
    """
    Initialize base subject for recon-all processing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        log_file: Path to the local log file for output.
        status_file: Path to the status file to append logs.
        cmd_file: Path to the command file to append execution commands.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RcaBaseInitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RCA_BASE_INIT_METADATA)
    cargs = []
    if log_file is not None:
        cargs.extend([
            "-init",
            "rca-base" + log_file
        ])
    if status_file is not None:
        cargs.append(status_file)
    if cmd_file is not None:
        cargs.append(cmd_file)
    ret = RcaBaseInitOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RCA_BASE_INIT_METADATA",
    "RcaBaseInitOutputs",
    "rca_base_init",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMG2IMGCOORD_METADATA = Metadata(
    id="c0184a18acdc535cdea447e6dcf5b37d6e69053d.boutiques",
    name="img2imgcoord",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Img2imgcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `img2imgcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def img2imgcoord(
    coordinates_file: str,
    source_image: InputPathType,
    dest_image: InputPathType,
    affine_transform: InputPathType,
    warp_field: InputPathType | None = None,
    pre_warp_affine: InputPathType | None = None,
    coords_in_voxels: bool = False,
    coords_in_mm: bool = False,
    verbose: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> Img2imgcoordOutputs:
    """
    Tool for transforming coordinates between images.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        coordinates_file: Filename containing coordinates.
        source_image: Filename of source image.
        dest_image: Filename of destination image.
        affine_transform: Filename of affine transform (e.g. source2dest.mat).
        warp_field: Filename of warpfield (e.g. intermediate2dest_warp.nii.gz).
        pre_warp_affine: Filename of pre-warp affine transform\
            (default=identity).
        coords_in_voxels: All coordinates in voxels (default).
        coords_in_mm: All coordinates in mm.
        verbose: Verbose mode.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Img2imgcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMG2IMGCOORD_METADATA)
    cargs = []
    cargs.append("img2imgcoord")
    cargs.append(coordinates_file)
    cargs.extend([
        "-src",
        execution.input_file(source_image)
    ])
    cargs.extend([
        "-dest",
        execution.input_file(dest_image)
    ])
    cargs.extend([
        "-xfm",
        execution.input_file(affine_transform)
    ])
    if warp_field is not None:
        cargs.extend([
            "-warp",
            execution.input_file(warp_field)
        ])
    if pre_warp_affine is not None:
        cargs.extend([
            "-premat",
            execution.input_file(pre_warp_affine)
        ])
    if coords_in_voxels:
        cargs.append("-vox")
    if coords_in_mm:
        cargs.append("-mm")
    if verbose:
        cargs.append("-v")
    if help_:
        cargs.append("-help")
    ret = Img2imgcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMG2IMGCOORD_METADATA",
    "Img2imgcoordOutputs",
    "img2imgcoord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WHIRLGIF_METADATA = Metadata(
    id="5014f57fafa702ba3b19014ba3566e92f5e47369.boutiques",
    name="whirlgif",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class WhirlgifOutputs(typing.NamedTuple):
    """
    Output object returned when calling `whirlgif(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """The generated GIF animation"""


def whirlgif(
    input_files: list[InputPathType],
    outfile: InputPathType | None = None,
    loop_count: int | None = None,
    delay_time: int | None = None,
    disp_flag: typing.Literal["none", "back", "prev", "not"] | None = None,
    list_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> WhirlgifOutputs:
    """
    GIF animation tool.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_files: Input image files for the animation.
        outfile: Specify the output file.
        loop_count: Specify the loop count for the animation.
        delay_time: Specify the delay time between frames.
        disp_flag: Specify the disposal method for frames.
        list_file: Input list file containing names of images to be used for\
            animation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WhirlgifOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WHIRLGIF_METADATA)
    cargs = []
    cargs.append("whirlgif")
    if outfile is not None:
        cargs.extend([
            "-o",
            execution.input_file(outfile)
        ])
    if loop_count is not None:
        cargs.extend([
            "-loop",
            str(loop_count)
        ])
    if delay_time is not None:
        cargs.extend([
            "-time",
            str(delay_time)
        ])
    if disp_flag is not None:
        cargs.extend([
            "-disp",
            disp_flag
        ])
    if list_file is not None:
        cargs.extend([
            "-i",
            execution.input_file(list_file)
        ])
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = WhirlgifOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(outfile).name) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WHIRLGIF_METADATA",
    "WhirlgifOutputs",
    "whirlgif",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_TESSELLATE_METADATA = Metadata(
    id="9dcf92c1d5089255feba7b2627ab0237e0be1c67.boutiques",
    name="mri_tessellate",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriTessellateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_tessellate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType
    """Output file of the tessellation surface, typically ?h.orig."""


def mri_tessellate(
    input_volume: InputPathType,
    label_value: int,
    output_surf: str,
    different_labels: bool = False,
    max_vertices: int | None = None,
    real_ras: bool = False,
    runner: Runner | None = None,
) -> MriTessellateOutputs:
    """
    This program creates a surface by tessellating a given input volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume (e.g., a filled MRI image).
        label_value: Label value for the tessellation. Integer value, if input\
            is filled volume, 127 is rh, 255 is lh.
        output_surf: Binary surface of the tessellation, output file.
        different_labels: Tessellate the surface of all voxels with different\
            labels.
        max_vertices: Set the max number of vertices to nvertices, and the max\
            number of faces to (2 * nvertices).
        real_ras: Save surface with real RAS coordinates where c_(r,a,s) != 0.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriTessellateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_TESSELLATE_METADATA)
    cargs = []
    cargs.append("mri_tessellate")
    cargs.append(execution.input_file(input_volume))
    cargs.append(str(label_value))
    cargs.append(output_surf)
    if different_labels:
        cargs.append("-a")
    if max_vertices is not None:
        cargs.extend([
            "-maxv",
            str(max_vertices)
        ])
    if real_ras:
        cargs.append("-n")
    ret = MriTessellateOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file(output_surf),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_TESSELLATE_METADATA",
    "MriTessellateOutputs",
    "mri_tessellate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BIASFIELD_METADATA = Metadata(
    id="c8391deeed6d412683183d406717be9cba1af3b4.boutiques",
    name="biasfield",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BiasfieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `biasfield(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    biasfield_output: OutputPathType
    """Generated bias field in the subject MRI directory"""
    rawavg_cor_norm: OutputPathType
    """The rawavg.mgz in 256^3, 1mm^3 space with the bias field removed"""


def biasfield(
    subject: str,
    tmpdir: str | None = None,
    no_cleanup: bool = False,
    help_: bool = False,
    debug: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> BiasfieldOutputs:
    """
    Computes the bias field by dividing the (unconformed) orig.mgz by the norm.mgz.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        tmpdir: Temporary directory.
        no_cleanup: Prevent cleanup of temporary files.
        help_: Display help information.
        debug: Enable debugging mode.
        version: Display script version info.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BiasfieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BIASFIELD_METADATA)
    cargs = []
    cargs.append("biasfield")
    cargs.extend([
        "--s",
        subject
    ])
    if tmpdir is not None:
        cargs.extend([
            "--tmp",
            tmpdir
        ])
    if no_cleanup:
        cargs.append("--nocleanup")
    if help_:
        cargs.append("--help")
    if debug:
        cargs.append("--debug")
    if version:
        cargs.append("--version")
    ret = BiasfieldOutputs(
        root=execution.output_file("."),
        biasfield_output=execution.output_file("biasfield.mgz"),
        rawavg_cor_norm=execution.output_file("rawavg.cor.norm.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BIASFIELD_METADATA",
    "BiasfieldOutputs",
    "biasfield",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_CAPTURE_PLANE_METADATA = Metadata(
    id="b2bfd3d4513396540148947511ec229d0418fc44.boutiques",
    name="volume-capture-plane",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeCapturePlaneOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_capture_plane(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_capture_plane(
    volume: InputPathType,
    subvolume: str,
    interp: str,
    h_dim: int,
    v_dim: int,
    scale_min: float,
    scale_max: float,
    bottom_left_x: float,
    bottom_left_y: float,
    bottom_left_z: float,
    bottom_right_x: float,
    bottom_right_y: float,
    bottom_right_z: float,
    top_left_x: float,
    top_left_y: float,
    top_left_z: float,
    image: str,
    runner: Runner | None = None,
) -> VolumeCapturePlaneOutputs:
    """
    Interpolate image from plane through volume.
    
    NOTE: If you want to generate an image with all of the capabilities of the
    GUI rendering, see -show-scene.
    
    Renders an image of an arbitrary plane through the volume file, with a
    simple linear grayscale palette. The parameter <interp> must be one of:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the volume file to interpolate from.
        subvolume: the name or number of the subvolume to use.
        interp: interpolation type.
        h_dim: width of output image, in pixels.
        v_dim: height of output image, in pixels.
        scale_min: value to render as black.
        scale_max: value to render as white.
        bottom_left_x: x-coordinate of the bottom left of the output image.
        bottom_left_y: y-coordinate of the bottom left of the output image.
        bottom_left_z: z-coordinate of the bottom left of the output image.
        bottom_right_x: x-coordinate of the bottom right of the output image.
        bottom_right_y: y-coordinate of the bottom right of the output image.
        bottom_right_z: z-coordinate of the bottom right of the output image.
        top_left_x: x-coordinate of the top left of the output image.
        top_left_y: y-coordinate of the top left of the output image.
        top_left_z: z-coordinate of the top left of the output image.
        image: output - the output image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCapturePlaneOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_CAPTURE_PLANE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-capture-plane")
    cargs.append(execution.input_file(volume))
    cargs.append(subvolume)
    cargs.append(interp)
    cargs.append(str(h_dim))
    cargs.append(str(v_dim))
    cargs.append(str(scale_min))
    cargs.append(str(scale_max))
    cargs.append(str(bottom_left_x))
    cargs.append(str(bottom_left_y))
    cargs.append(str(bottom_left_z))
    cargs.append(str(bottom_right_x))
    cargs.append(str(bottom_right_y))
    cargs.append(str(bottom_right_z))
    cargs.append(str(top_left_x))
    cargs.append(str(top_left_y))
    cargs.append(str(top_left_z))
    cargs.append(image)
    ret = VolumeCapturePlaneOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_CAPTURE_PLANE_METADATA",
    "VolumeCapturePlaneOutputs",
    "volume_capture_plane",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GAUSS_4DFP_METADATA = Metadata(
    id="33be7b3b1fc943cdc73ad39caf02b12c7b7d7be5.boutiques",
    name="gauss_4dfp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Gauss4dfpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gauss_4dfp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output file in 4dfp format."""


def gauss_4dfp(
    input_file: str,
    f_half: float,
    output_root: str | None = None,
    endian_flag: str | None = None,
    wrap_flag: bool = False,
    differentiate_flag: bool = False,
    runner: Runner | None = None,
) -> Gauss4dfpOutputs:
    """
    Applies a Gaussian filter to 4dfp or conc input files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input 4dfp or conc file to be processed.
        f_half: Half frequency in 1/cm for the Gaussian filter application\
            (f_half is the half frequency in 1/cm).
        output_root: Root name for the output file. Default is\
            <inroot>_g<10*f_half>.
        endian_flag: Specify output endian; 'b' for big or 'l' for little\
            endian. Default is input endian.
        wrap_flag: Suppress x and y padding (wrap-around).
        differentiate_flag: Apply differentiation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Gauss4dfpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GAUSS_4DFP_METADATA)
    cargs = []
    cargs.append("gauss_4dfp")
    cargs.append(input_file)
    cargs.append(str(f_half))
    if output_root is not None:
        cargs.append(output_root)
    if endian_flag is not None:
        cargs.extend([
            "-@",
            endian_flag
        ])
    if wrap_flag:
        cargs.append("-w")
    if differentiate_flag:
        cargs.append("-d")
    ret = Gauss4dfpOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_root + ".4dfp.ifh") if (output_root is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GAUSS_4DFP_METADATA",
    "Gauss4dfpOutputs",
    "gauss_4dfp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_HISTO_EQ_METADATA = Metadata(
    id="d08f7a1c281046fe105c26dd1e467523f2a9672c.boutiques",
    name="mri_histo_eq",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriHistoEqOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_histo_eq(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_histo_eq(
    input_volume_1: InputPathType,
    input_volume_2: InputPathType,
    runner: Runner | None = None,
) -> MriHistoEqOutputs:
    """
    MRI histogram equalization tool from Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume_1: Input volume 1.
        input_volume_2: Input volume 2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriHistoEqOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_HISTO_EQ_METADATA)
    cargs = []
    cargs.append("mri_histo_eq")
    cargs.append(execution.input_file(input_volume_1))
    cargs.append(execution.input_file(input_volume_2))
    ret = MriHistoEqOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_HISTO_EQ_METADATA",
    "MriHistoEqOutputs",
    "mri_histo_eq",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIRST_UTILS_METADATA = Metadata(
    id="751b014c963ee8344146242e7dac5534b50bf3cd.boutiques",
    name="first_utils",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FirstUtilsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `first_utils(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def first_utils(
    input_file: InputPathType,
    output_name: str,
    norm_factors: InputPathType | None = None,
    reference_image: InputPathType | None = None,
    extra_path: InputPathType | None = None,
    flirt_matrices: InputPathType | None = None,
    use_scale: bool = False,
    dice_overlap: bool = False,
    input_mesh: InputPathType | None = None,
    use_norm: bool = False,
    surface_out: bool = False,
    threshold: float | None = None,
    mesh_label: str | None = None,
    use_bvars: bool = False,
    use_recon_mni: bool = False,
    vertex_analysis: bool = False,
    use_recon_native: bool = False,
    use_rigid_align: bool = False,
    design_matrix: InputPathType | None = None,
    recon_mesh_from_bvars: bool = False,
    read_bvars: bool = False,
    mesh_to_vol: bool = False,
    centre_origin: bool = False,
    save_vertices: InputPathType | None = None,
    verbose: bool = False,
    use_pca_filter: bool = False,
    num_modes: float | None = None,
    single_boundary_corr: bool = False,
    do_mvglm: bool = False,
    concat_bvars: bool = False,
    debug_mode: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> FirstUtilsOutputs:
    """
    Utilities for handling FIRST's input and output files.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Filename of input image/mesh/bvars.
        output_name: Output name.
        norm_factors: Filename of normalization factors.
        reference_image: Filename of reference image.
        extra_path: Specifies extra path to image in .bvars file.
        flirt_matrices: Text file containing filenames of flirt matrices.
        use_scale: Do stats.
        dice_overlap: Calculates Dice overlap.
        input_mesh: Filename of input mesh.
        use_norm: Normalize volumes measurements.
        surface_out: Output vertex analysis on the surface.
        threshold: Threshold for clean up.
        mesh_label: Specifies the label used to fill the mesh.
        use_bvars: Operate using the mode parameters output from FIRST.
        use_recon_mni: Reconstruct meshes in MNI space.
        vertex_analysis: Perform vertex-wise stats from bvars.
        use_recon_native: Reconstruct meshes in native space.
        use_rigid_align: Register meshes using 6 degree of freedom (7 if\
            useScale is used).
        design_matrix: Filename of fsl design matrix.
        recon_mesh_from_bvars: Convert bvars to mesh.
        read_bvars: Read bvars from binary format.
        mesh_to_vol: Convert mesh to an image.
        centre_origin: Places origin of mesh at the centre of the image.
        save_vertices: Filename for saving matrix of vertex coords: (all x,\
            then all y, then all z) by Nsubjects.
        verbose: Output F-stats to standard out.
        use_pca_filter: Smooths the surface by truncating the mode parameters.
        num_modes: Number of modes to retain per structure.
        single_boundary_corr: Correct boundary voxels of a single structure.
        do_mvglm: Perform multivariate general linear model analysis.
        concat_bvars: Concat bvars from binary format.
        debug_mode: Turn on debugging mode.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FirstUtilsOutputs`).
    """
    if threshold is not None and not (0 <= threshold): 
        raise ValueError(f"'threshold' must be greater than 0 <= x but was {threshold}")
    if num_modes is not None and not (0 <= num_modes): 
        raise ValueError(f"'num_modes' must be greater than 0 <= x but was {num_modes}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIRST_UTILS_METADATA)
    cargs = []
    cargs.append("first_utils")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_name
    ])
    if norm_factors is not None:
        cargs.extend([
            "-g",
            execution.input_file(norm_factors)
        ])
    if reference_image is not None:
        cargs.extend([
            "-r",
            execution.input_file(reference_image)
        ])
    if extra_path is not None:
        cargs.extend([
            "-a",
            execution.input_file(extra_path)
        ])
    if flirt_matrices is not None:
        cargs.extend([
            "-f",
            execution.input_file(flirt_matrices)
        ])
    if use_scale:
        cargs.append("--useScale")
    if dice_overlap:
        cargs.append("--overlap")
    if input_mesh is not None:
        cargs.extend([
            "-m",
            execution.input_file(input_mesh)
        ])
    if use_norm:
        cargs.append("--useNorm")
    if surface_out:
        cargs.append("--surfaceout")
    if threshold is not None:
        cargs.extend([
            "-p",
            str(threshold)
        ])
    if mesh_label is not None:
        cargs.extend([
            "-l",
            mesh_label
        ])
    if use_bvars:
        cargs.append("--usebvars")
    if use_recon_mni:
        cargs.append("--useReconMNI")
    if vertex_analysis:
        cargs.append("--vertexAnalysis")
    if use_recon_native:
        cargs.append("--useReconNative")
    if use_rigid_align:
        cargs.append("--useRigidAlign")
    if design_matrix is not None:
        cargs.extend([
            "-d",
            execution.input_file(design_matrix)
        ])
    if recon_mesh_from_bvars:
        cargs.append("--reconMeshFromBvars")
    if read_bvars:
        cargs.append("--readBvars")
    if mesh_to_vol:
        cargs.append("--meshToVol")
    if centre_origin:
        cargs.append("--centreOrigin")
    if save_vertices is not None:
        cargs.extend([
            "--saveVertices",
            execution.input_file(save_vertices)
        ])
    if verbose:
        cargs.append("-v")
    if use_pca_filter:
        cargs.append("--usePCAfilter")
    if num_modes is not None:
        cargs.extend([
            "-n",
            str(num_modes)
        ])
    if single_boundary_corr:
        cargs.append("--singleBoundaryCorr")
    if do_mvglm:
        cargs.append("--doMVGLM")
    if concat_bvars:
        cargs.append("--concatBvars")
    if debug_mode:
        cargs.append("--debug")
    if help_:
        cargs.append("-h")
    ret = FirstUtilsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIRST_UTILS_METADATA",
    "FirstUtilsOutputs",
    "first_utils",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SH2AMP_METADATA = Metadata(
    id="b88a6fe01eede507fd3fd0ee64c193a8f9c85310.boutiques",
    name="sh2amp",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Sh2ampFslgrad:
    """
    Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used.
    """
    bvecs: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    bvals: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fslgrad")
        cargs.append(execution.input_file(self.bvecs))
        cargs.append(execution.input_file(self.bvals))
        return cargs


@dataclasses.dataclass
class Sh2ampVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class Sh2ampVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


@dataclasses.dataclass
class Sh2ampConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Sh2ampOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sh2amp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image consisting of the amplitude of the SH functions along
    the specified directions."""


def sh2amp(
    input_: InputPathType,
    directions: InputPathType,
    output: str,
    nonnegative: bool = False,
    grad: InputPathType | None = None,
    fslgrad: Sh2ampFslgrad | None = None,
    strides: typing.Union[Sh2ampVariousString, Sh2ampVariousFile] | None = None,
    datatype: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Sh2ampConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Sh2ampOutputs:
    """
    Evaluate the amplitude of an image of spherical harmonic functions along
    specified directions.
    
    The input image should consist of a 4D or 5D image, with SH coefficients
    along the 4th dimension according to the convention below. If 4D (or size 1
    along the 5th dimension), the program expects to be provided with a single
    shell of directions. If 5D, each set of coefficients along the 5th dimension
    is understood to correspond to a different shell.
    
    The directions can be provided as:
    - a 2-column ASCII text file contained azimuth / elevation pairs (as
    produced by dirgen)
    - a 3-column ASCII text file containing x, y, z Cartesian direction vectors
    (as produced by dirgen -cart)
    - a 4-column ASCII text file containing the x, y, z, b components of a full
    DW encoding scheme (in MRtrix format, see main documentation for details).
    - an image file whose header contains a valid DW encoding scheme
    
    If a full DW encoding is provided, the number of shells needs to match those
    found in the input image of coefficients (i.e. its size along the 5th
    dimension). If needed, the -shell option can be used to pick out the
    specific shell(s) of interest.
    
    If the input image contains multiple shells (its size along the 5th
    dimension is greater than one), the program will expect the direction set to
    contain multiple shells, which can only be provided as a full DW encodings
    (the last two options in the list above).
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: the input image consisting of spherical harmonic (SH)\
            coefficients.
        directions: the list of directions along which the SH functions will be\
            sampled, generated using the dirgen command.
        output: the output image consisting of the amplitude of the SH\
            functions along the specified directions.
        nonnegative: cap all negative amplitudes to zero.
        grad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in a text file. This should be supplied as a 4xN text file\
            with each line is in the format [ X Y Z b ], where [ X Y Z ] describe\
            the direction of the applied gradient, and b gives the b-value in units\
            of s/mm^2. If a diffusion gradient scheme is present in the input image\
            header, the data provided with this option will be instead used.
        fslgrad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in FSL bvecs/bvals format files. If a diffusion gradient\
            scheme is present in the input image header, the data provided with\
            this option will be instead used.
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Sh2ampOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SH2AMP_METADATA)
    cargs = []
    cargs.append("sh2amp")
    if nonnegative:
        cargs.append("-nonnegative")
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if fslgrad is not None:
        cargs.extend(fslgrad.run(execution))
    if strides is not None:
        cargs.extend([
            "-strides",
            *strides.run(execution)
        ])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(execution.input_file(directions))
    cargs.append(output)
    ret = Sh2ampOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SH2AMP_METADATA",
    "Sh2ampConfig",
    "Sh2ampFslgrad",
    "Sh2ampOutputs",
    "Sh2ampVariousFile",
    "Sh2ampVariousString",
    "sh2amp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MKHEADSURF_METADATA = Metadata(
    id="d268c25e144e66d66d451c811baf8b76c969e6ec.boutiques",
    name="mkheadsurf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MkheadsurfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mkheadsurf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mkheadsurf(
    input_vol: InputPathType,
    output_vol: str,
    output_surf: str,
    subject_id: str,
    nsmooth: float | None = None,
    noseghead: bool = False,
    thresh1: float | None = None,
    thresh2: float | None = None,
    nhitsmin: float | None = None,
    ndilate: float | None = None,
    nerode: float | None = None,
    fillval: float | None = None,
    fhi: float | None = None,
    no_rescale: bool = False,
    no_fill_holes_islands: bool = False,
    or_mask: InputPathType | None = None,
    tessellation_method: str | None = None,
    inflate: bool = False,
    curv: bool = False,
    srcvol: str | None = None,
    headvol: str | None = None,
    headsurf: str | None = None,
    smheadsurf: str | None = None,
    hemi: str | None = None,
    subjects_dir: str | None = None,
    umask: float | None = None,
    logfile: str | None = None,
    runner: Runner | None = None,
) -> MkheadsurfOutputs:
    """
    Segment and create a surface representation of the head for visualization and
    further processing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_vol: Input volume.
        output_vol: Output volume.
        output_surf: Output surface.
        subject_id: Subject ID.
        nsmooth: Number of smoothing iterations (default 10).
        noseghead: Do not segment the head, only tessellate and smooth existing.
        thresh1: Threshold 1 value (default 20).
        thresh2: Threshold 2 value (default 20).
        nhitsmin: Minimum number of hits (default 2).
        ndilate: Number of dilations (default 0).
        nerode: Number of erosions (default 0).
        fillval: Fill value (default 1).
        fhi: FHI for MRIchangeType; default is to use default in mri_seghead.
        no_rescale: Do not rescale input when converting to uchar.
        no_fill_holes_islands: Do not fill holes and remove islands.
        or_mask: Include all voxels in ormask in the head seg.
        tessellation_method: Tessellation method using mri_tessellate or mri_mc\
            (default is -mc).
        inflate: Inflate and compute sulc.
        curv: Compute curv with smoothing.
        srcvol: Source volume ID (default is T1).
        headvol: Head volume ID (default is seghead).
        headsurf: Head surface ID (default is seghead).
        smheadsurf: Smoothed head surface ID (default is smseghead).
        hemi: Hemisphere (default is lh).
        subjects_dir: Subjects directory (default is SUBJECTS_DIR).
        umask: Umask setting (default is 2).
        logfile: Log file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MkheadsurfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MKHEADSURF_METADATA)
    cargs = []
    cargs.append("mkheadsurf")
    cargs.extend([
        "-i",
        execution.input_file(input_vol)
    ])
    cargs.extend([
        "-o",
        output_vol
    ])
    cargs.extend([
        "-surf",
        output_surf
    ])
    cargs.extend([
        "-s",
        subject_id
    ])
    if nsmooth is not None:
        cargs.extend([
            "-nsmooth",
            str(nsmooth)
        ])
    if noseghead:
        cargs.append("-noseghead")
    if thresh1 is not None:
        cargs.extend([
            "-thresh1",
            str(thresh1)
        ])
    if thresh2 is not None:
        cargs.extend([
            "-thresh2",
            str(thresh2)
        ])
    if nhitsmin is not None:
        cargs.extend([
            "-nhitsmin",
            str(nhitsmin)
        ])
    if ndilate is not None:
        cargs.extend([
            "-ndilate",
            str(ndilate)
        ])
    if nerode is not None:
        cargs.extend([
            "-nerode",
            str(nerode)
        ])
    if fillval is not None:
        cargs.extend([
            "-fillval",
            str(fillval)
        ])
    if fhi is not None:
        cargs.extend([
            "-fhi",
            str(fhi)
        ])
    if no_rescale:
        cargs.append("-no-rescale")
    if no_fill_holes_islands:
        cargs.append("-no-fill-holes-islands")
    if or_mask is not None:
        cargs.extend([
            "-or-mask",
            execution.input_file(or_mask)
        ])
    if tessellation_method is not None:
        cargs.extend([
            "-tess",
            tessellation_method
        ])
    if inflate:
        cargs.append("-inflate")
    if curv:
        cargs.append("-curv")
    if srcvol is not None:
        cargs.extend([
            "-srcvol",
            srcvol
        ])
    if headvol is not None:
        cargs.extend([
            "-headvol",
            headvol
        ])
    if headsurf is not None:
        cargs.extend([
            "-headsurf",
            headsurf
        ])
    if smheadsurf is not None:
        cargs.extend([
            "-smheadsurf",
            smheadsurf
        ])
    if hemi is not None:
        cargs.extend([
            "-hemi",
            hemi
        ])
    if subjects_dir is not None:
        cargs.extend([
            "-sd",
            subjects_dir
        ])
    if umask is not None:
        cargs.extend([
            "-umask",
            str(umask)
        ])
    if logfile is not None:
        cargs.extend([
            "-log",
            logfile
        ])
    ret = MkheadsurfOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MKHEADSURF_METADATA",
    "MkheadsurfOutputs",
    "mkheadsurf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CNR_METADATA = Metadata(
    id="e426f06fe9ac260492b56203731c6940db9a022d.boutiques",
    name="mri_cnr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCnrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_cnr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_cnr(
    surf_dir: str,
    volume_files: list[InputPathType],
    slope: list[str] | None = None,
    logfile: str | None = None,
    labels: list[str] | None = None,
    print_total_cnr: bool = False,
    version_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> MriCnrOutputs:
    """
    Compute the gray/white/csf contrast-to-noise ratio for volumes using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surf_dir: Directory containing surface data.
        volume_files: Volumes to process.
        slope: Compute slope and write to files labeled with slope_fname.\
            Requires four additional values: dist_in, dist_out, step_in, and\
            step_out.
        logfile: Log CNR to specified logfile. Will contain 8 values in a\
            specific order: gray_white_cnr, gray_csf_cnr, white_mean, gray_mean,\
            csf_mean, sqrt(white_var), sqrt(gray_var), sqrt(csf_var).
        labels: Read hemisphere labels from specified left and right hemisphere\
            files.
        print_total_cnr: Print only the total CNR to stdout.
        version_flag: Print software version information and quit.
        help_flag: Print usage information and quit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCnrOutputs`).
    """
    if slope is not None and (len(slope) != 5): 
        raise ValueError(f"Length of 'slope' must be 5 but was {len(slope)}")
    if labels is not None and (len(labels) != 2): 
        raise ValueError(f"Length of 'labels' must be 2 but was {len(labels)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CNR_METADATA)
    cargs = []
    cargs.append("mri_cnr")
    cargs.append(surf_dir)
    cargs.extend([execution.input_file(f) for f in volume_files])
    if slope is not None:
        cargs.extend([
            "-s",
            *slope
        ])
    if logfile is not None:
        cargs.extend([
            "-l",
            logfile
        ])
    if labels is not None:
        cargs.extend([
            "label",
            *labels
        ])
    if print_total_cnr:
        cargs.append("-t")
    if version_flag:
        cargs.append("-version")
    if help_flag:
        cargs.append("-help")
    ret = MriCnrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CNR_METADATA",
    "MriCnrOutputs",
    "mri_cnr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_JOINT_TENSOR_FUSION_METADATA = Metadata(
    id="0060c77e83025b09ff07322e714ad4f9d9337634.boutiques",
    name="antsJointTensorFusion",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsJointTensorFusionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_joint_tensor_fusion(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_fusion_image: OutputPathType
    """The label fusion image output."""
    intensity_fusion_image: OutputPathType
    """The intensity fusion image output."""
    label_posterior_probability_image: OutputPathType
    """The label posterior probability images."""
    atlas_voting_weight_image: OutputPathType
    """The atlas voting weight images."""


def ants_joint_tensor_fusion(
    target_image: list[str],
    atlas_image: list[str],
    atlas_segmentation: InputPathType,
    output: str,
    dimensionality: typing.Literal[2, 3, 4] | None = None,
    alpha: float | None = 0.1,
    beta: float | None = 2.0,
    retain_label_posterior_images: typing.Literal[0, 1] | None = None,
    retain_atlas_voting_images: typing.Literal[0, 1] | None = None,
    constrain_nonnegative: typing.Literal[0, 1] | None = None,
    log_euclidean: typing.Literal[0, 1] | None = None,
    patch_radius: str | None = None,
    patch_metric: typing.Literal["PC", "MSQ"] | None = None,
    search_radius: str | None = None,
    exclusion_image: str | None = None,
    mask_image: InputPathType | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AntsJointTensorFusionOutputs:
    """
    antsJointTensorFusion is an image fusion algorithm developed by Hongzhi Wang and
    Paul Yushkevich which won segmentation challenges at MICCAI 2012 and MICCAI
    2013. The original label fusion framework was extended to accommodate
    intensities by Brian Avants. This implementation is based on the original
    ITK-style implementation and ANTsR implementation.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        target_image: The target image (or multimodal target images) assumed to\
            be aligned to a common image domain.
        atlas_image: The atlas image (or multimodal atlas images) assumed to be\
            aligned to a common image domain.
        atlas_segmentation: The atlas segmentation images. For performing label\
            fusion the number of specified segmentations should be identical to the\
            number of atlas image sets.
        output: The output is the intensity and/or label fusion image.\
            Additional optional outputs include the label posterior probability\
            images and the atlas voting weight images.
        dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        alpha: Regularization term added to matrix Mx for calculating the\
            inverse. Default = 0.1.
        beta: Exponent for mapping intensity difference to the joint error.\
            Default = 2.0.
        retain_label_posterior_images: Retain label posterior probability\
            images. Requires atlas segmentations to be specified. Default = false.
        retain_atlas_voting_images: Retain atlas voting images. Default = false.
        constrain_nonnegative: Constrain solution to non-negative weights.
        log_euclidean: Use log Euclidean space for tensor math.
        patch_radius: Patch radius for similarity measures. Default = 2x2x2.
        patch_metric: Metric to be used in determining the most similar\
            neighborhood patch. Options include Pearson's correlation (PC) and mean\
            squares (MSQ). Default = PC.
        search_radius: Search radius for similarity measures. Default = 3x3x3.
        exclusion_image: Specify an exclusion region for the given label.
        mask_image: If a mask image is specified, fusion is only performed in\
            the mask region.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsJointTensorFusionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_JOINT_TENSOR_FUSION_METADATA)
    cargs = []
    cargs.append("antsJointTensorFusion")
    if dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(dimensionality)
        ])
    cargs.extend([
        "-t",
        ",".join(target_image)
    ])
    cargs.extend([
        "-g",
        ",".join(atlas_image)
    ])
    cargs.extend([
        "-l",
        execution.input_file(atlas_segmentation)
    ])
    if alpha is not None:
        cargs.extend([
            "-a",
            str(alpha)
        ])
    if beta is not None:
        cargs.extend([
            "-b",
            str(beta)
        ])
    if retain_label_posterior_images is not None:
        cargs.extend([
            "-r",
            str(retain_label_posterior_images)
        ])
    if retain_atlas_voting_images is not None:
        cargs.extend([
            "-f",
            str(retain_atlas_voting_images)
        ])
    if constrain_nonnegative is not None:
        cargs.extend([
            "-c",
            str(constrain_nonnegative)
        ])
    if log_euclidean is not None:
        cargs.extend([
            "-u",
            str(log_euclidean)
        ])
    if patch_radius is not None:
        cargs.extend([
            "-p",
            patch_radius
        ])
    if patch_metric is not None:
        cargs.extend([
            "-m",
            patch_metric
        ])
    if search_radius is not None:
        cargs.extend([
            "-s",
            search_radius
        ])
    if exclusion_image is not None:
        cargs.extend([
            "-e",
            exclusion_image
        ])
    if mask_image is not None:
        cargs.extend([
            "-x",
            execution.input_file(mask_image)
        ])
    cargs.extend([
        "-o",
        output
    ])
    if verbose is not None:
        cargs.extend([
            "-v",
            str(verbose)
        ])
    ret = AntsJointTensorFusionOutputs(
        root=execution.output_file("."),
        label_fusion_image=execution.output_file(output + "_LabelFusion.nii.gz"),
        intensity_fusion_image=execution.output_file(output + "_IntensityFusion.nii.gz"),
        label_posterior_probability_image=execution.output_file(output + "_LabelPosterior.nii.gz"),
        atlas_voting_weight_image=execution.output_file(output + "_AtlasVoting.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_JOINT_TENSOR_FUSION_METADATA",
    "AntsJointTensorFusionOutputs",
    "ants_joint_tensor_fusion",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONF2HIRES_METADATA = Metadata(
    id="0daec93cecaaf674dbbc3d770b70999cf8bff082.boutiques",
    name="conf2hires",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Conf2hiresOutputs(typing.NamedTuple):
    """
    Output object returned when calling `conf2hires(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def conf2hires(
    subject: str,
    no_t2: bool = False,
    mm_norm_sigma: float | None = 8,
    no_flair: bool = False,
    threads: float | None = None,
    copy_bias_from_conf: bool = False,
    norm_opts_rca: bool = False,
    trilin: bool = False,
    no_dev: bool = False,
    bbr_t2: bool = False,
    first_peak_d1: bool = False,
    first_peak_d2: bool = False,
    stopmask: str | None = None,
    expert: str | None = None,
    force_update: bool = False,
    runner: Runner | None = None,
) -> Conf2hiresOutputs:
    """
    Places the surfaces on high resolution T1 (and maybe T2) volumes based on an
    initial placement on a conformed volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        no_t2: Disable T2 processing (default).
        mm_norm_sigma: Smoothing level for T2 mri_normalize (default is 8).
        no_flair: Disable FLAIR processing (default).
        threads: Number of threads to use.
        copy_bias_from_conf: Copy bias field from conformed instead of\
            computing directly.
        norm_opts_rca: Compute bias directly using recon-all opts to\
            mri_normalize.
        trilin: Use trilinear normalization (default, applies with\
            --copy-bias-from-conf).
        no_dev: Do not use mris_make_surfaces.dev (default).
        bbr_t2: Set BBR contrast type to t2.
        first_peak_d1: Refine surface targets in MRIScomputeBorderValues()\
            using first peak method D1.
        first_peak_d2: Refine surface targets in MRIScomputeBorderValues()\
            using first peak method D2.
        stopmask: Specify stop mask.
        expert: Use expert options.
        force_update: Force update of final surfaces.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Conf2hiresOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONF2HIRES_METADATA)
    cargs = []
    cargs.append("conf2hires")
    cargs.extend([
        "--s",
        subject
    ])
    if no_t2:
        cargs.append("--no-t2")
    if mm_norm_sigma is not None:
        cargs.extend([
            "--mm-norm-sigma",
            str(mm_norm_sigma)
        ])
    if no_flair:
        cargs.append("--no-flair")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if copy_bias_from_conf:
        cargs.append("--copy-bias-from-conf")
    if norm_opts_rca:
        cargs.append("--norm-opts-rca")
    if trilin:
        cargs.append("--trilin")
    if no_dev:
        cargs.append("--no-dev")
    if bbr_t2:
        cargs.append("--bbr-t2")
    if first_peak_d1:
        cargs.append("--first-peak-d1")
    if first_peak_d2:
        cargs.append("--first-peak-d2")
    if stopmask is not None:
        cargs.extend([
            "--stopmask",
            stopmask
        ])
    if expert is not None:
        cargs.extend([
            "--expert",
            expert
        ])
    if force_update:
        cargs.append("--force-update")
    ret = Conf2hiresOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONF2HIRES_METADATA",
    "Conf2hiresOutputs",
    "conf2hires",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CA_REGISTER_METADATA = Metadata(
    id="b27982b2cf32c82b5c162a9c2f5e298b284040cc.boutiques",
    name="mri_ca_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCaRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_ca_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Multidimensional transform in m3d format"""


def mri_ca_register(
    input_volume: InputPathType,
    template: InputPathType,
    output_volume: str,
    tolerance: float | None = None,
    mask: InputPathType | None = None,
    transform_lta: InputPathType | None = None,
    level: float | None = None,
    read_intensity: bool = False,
    align: bool = False,
    invert_save_file: str | None = None,
    distance: float | None = None,
    regularize: float | None = None,
    regularize_mean: float | None = None,
    scale_smoothness: float | None = None,
    nobright: bool = False,
    renormalize_map: bool = False,
    renormalize: InputPathType | None = None,
    read_lta: bool = False,
    smoothness: float | None = None,
    samples: float | None = None,
    nsmall: float | None = None,
    fixed: bool = False,
    optimal: bool = False,
    noneg: bool = False,
    wm: bool = False,
    min_avgs: float | None = None,
    transform_limit: float | None = None,
    relabel: float | None = None,
    relabel_avgs: float | None = None,
    reset_avgs: float | None = None,
    vf_file: str | None = None,
    diag_file: str | None = None,
    tr: float | None = None,
    te: float | None = None,
    example: str | None = None,
    bigventricles: bool = False,
    uncompress: bool = False,
    second_pass_renorm: bool = False,
    threads: float | None = None,
    runner: Runner | None = None,
) -> MriCaRegisterOutputs:
    """
    Generates a multi-dimensional talairach transform from a gca file and
    talairach.lta file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume.
        template: Template in GCA format.
        output_volume: Output volume in M3D format.
        tolerance: Defines convergence of registration.
        mask: Specifies volume to use as a mask.
        transform_lta: Transform in LTA format.
        level: Defines how many surrounding voxels will be used in\
            interpolations, default is 6.
        read_intensity: Allows reading of multiple intensity normalization.
        align: Enable alignment.
        invert_save_file: Invert and save as GCAM file.
        distance: Distance for registration.
        regularize: Regularization parameter.
        regularize_mean: Mean regularization.
        scale_smoothness: Smoothness scaling factor.
        nobright: Disable brightness adjustment.
        renormalize_map: Renormalize using map.
        renormalize: Renormalize with intensity file.
        read_lta: Use LTA file for registration.
        smoothness: Smoothness parameter.
        samples: Sample points for registration.
        nsmall: Number of small features.
        fixed: Fixed mode for registration.
        optimal: Optimal registration settings.
        noneg: Disallow negative values.
        wm: White matter flag.
        min_avgs: Minimum number of averages.
        transform_limit: Transform limit.
        relabel: Relabel options.
        relabel_avgs: Relabel averages.
        reset_avgs: Reset averages.
        vf_file: VF file name.
        diag_file: Diagnostic file name.
        tr: TR parameter.
        te: TE parameter.
        example: Example file.
        bigventricles: Handle big ventricles.
        uncompress: Uncompress files.
        second_pass_renorm: Second pass renormalization.
        threads: Number of threads.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCaRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CA_REGISTER_METADATA)
    cargs = []
    cargs.append("mri_ca_register")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(template))
    cargs.append(output_volume)
    if tolerance is not None:
        cargs.extend([
            "-tol",
            str(tolerance)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if transform_lta is not None:
        cargs.extend([
            "-T",
            execution.input_file(transform_lta)
        ])
    if level is not None:
        cargs.extend([
            "-level",
            str(level)
        ])
    if read_intensity:
        cargs.append("-ri")
    if align:
        cargs.append("-align")
    if invert_save_file is not None:
        cargs.extend([
            "-invert-and-save",
            invert_save_file
        ])
    if distance is not None:
        cargs.extend([
            "-dist",
            str(distance)
        ])
    if regularize is not None:
        cargs.extend([
            "-regularize",
            str(regularize)
        ])
    if regularize_mean is not None:
        cargs.extend([
            "-regularize-mean",
            str(regularize_mean)
        ])
    if scale_smoothness is not None:
        cargs.extend([
            "-scale_smoothness",
            str(scale_smoothness)
        ])
    if nobright:
        cargs.append("-nobright")
    if renormalize_map:
        cargs.append("-renormalize_map")
    if renormalize is not None:
        cargs.extend([
            "-renormalize",
            execution.input_file(renormalize)
        ])
    if read_lta:
        cargs.append("-read_lta")
    if smoothness is not None:
        cargs.extend([
            "-smoothness",
            str(smoothness)
        ])
    if samples is not None:
        cargs.extend([
            "-samples",
            str(samples)
        ])
    if nsmall is not None:
        cargs.extend([
            "-nsmall",
            str(nsmall)
        ])
    if fixed:
        cargs.append("-fixed")
    if optimal:
        cargs.append("-optimal")
    if noneg:
        cargs.append("-noneg")
    if wm:
        cargs.append("-wm")
    if min_avgs is not None:
        cargs.extend([
            "-min_avgs",
            str(min_avgs)
        ])
    if transform_limit is not None:
        cargs.extend([
            "-tl",
            str(transform_limit)
        ])
    if relabel is not None:
        cargs.extend([
            "-relabel",
            str(relabel)
        ])
    if relabel_avgs is not None:
        cargs.extend([
            "-relabel_avgs",
            str(relabel_avgs)
        ])
    if reset_avgs is not None:
        cargs.extend([
            "-reset_avgs",
            str(reset_avgs)
        ])
    if vf_file is not None:
        cargs.extend([
            "-vf",
            vf_file
        ])
    if diag_file is not None:
        cargs.extend([
            "-diag",
            diag_file
        ])
    if tr is not None:
        cargs.extend([
            "-tr",
            str(tr)
        ])
    if te is not None:
        cargs.extend([
            "-te",
            str(te)
        ])
    if example is not None:
        cargs.extend([
            "-example",
            example
        ])
    if bigventricles:
        cargs.append("-<no>bigventricles")
    if uncompress:
        cargs.append("-uncompress")
    if second_pass_renorm:
        cargs.append("-secondpassrenorm")
    if threads is not None:
        cargs.extend([
            "-threads",
            str(threads)
        ])
    ret = MriCaRegisterOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume + ".m3d"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CA_REGISTER_METADATA",
    "MriCaRegisterOutputs",
    "mri_ca_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MAT_SEL_PY_METADATA = Metadata(
    id="507d4511ca162d3a004cc7ca58b188298e3eea66.boutiques",
    name="fat_mat_sel.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMatSelPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mat_sel_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    individual_images: OutputPathType
    """Individual images of matrix plots."""
    matrix_grids: OutputPathType
    """Output matrix grid files."""
    v_1_d_dsets: OutputPathType
    """Output 1D dataset files."""


def fat_mat_sel_py(
    parameters: str,
    matr_in: str | None = None,
    list_match: InputPathType | None = None,
    out_ind_matr: bool = False,
    out_ind_1ddset: bool = False,
    hold_image: bool = False,
    extern_labs_no: bool = False,
    type_file: str | None = None,
    dpi_file: float | None = None,
    xlen_file: float | None = None,
    ylen_file: float | None = None,
    tight_layout_on: bool = False,
    fig_off: bool = False,
    size_font: float | None = None,
    lab_size_font: float | None = None,
    a_plotmin: float | None = None,
    b_plotmax: float | None = None,
    cbar_off: bool = False,
    map_of_colors: str | None = None,
    cbar_int_num: float | None = None,
    width_cbar_perc: float | None = None,
    specifier: str | None = None,
    xtick_lab_off: bool = False,
    runner: Runner | None = None,
) -> FatMatSelPyOutputs:
    """
    Perform simple matrix plotting operations from outputs of FATCAT programs
    3dNetCorr and 3dTrackID.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        parameters: Supply names of parameters, separated by whitespace, for\
            selecting from a matrix file.
        matr_in: Provide the set of matrix (*.grid or *.netcc) files by\
            searchable path. This can be a globbable entry in quotes containing\
            wildcard characters.
        list_match: Provide the matrix (*.grid or *.netcc) files by explicit\
            path, matched per file with a CSV subject ID.
        out_ind_matr: Output individual matrix files of properties.
        out_ind_1ddset: Output as a 1D dset, more easily readable by other\
            programs.
        hold_image: Switch to hold the Python-produced image on the output\
            screen until a key has been hit.
        extern_labs_no: Switch to turn off the usage of user-defined labels in\
            the *.grid/*.netcc files.
        type_file: Select image format type (e.g., jpg, png, pdf).
        dpi_file: Set resolution (dots per inch) of output image.
        xlen_file: Horizontal dimension of output saved image, in units of\
            inches.
        ylen_file: Vertical dimension of output saved image, in units of\
            inches.
        tight_layout_on: Use matplotlib's tight_layout() option to ensure no\
            overlap of features in the image.
        fig_off: Switch if you don't want matrix figure output.
        size_font: Set font size for colorbar and title.
        lab_size_font: Set font size for x- and y-axis labels.
        a_plotmin: Minimum colorbar value.
        b_plotmax: Maximum colorbar value.
        cbar_off: Switch to not include a colorbar at the right side of the\
            plot.
        map_of_colors: Change the colormap style used in the plot.
        cbar_int_num: Set the number of intervals on the colorbar.
        width_cbar_perc: Width of colorbar as percentage of width of the\
            correlation matrix.
        specifier: Specify number formatting for the colorbar numbers (e.g.,\
            '%.4f' for four decimal places).
        xtick_lab_off: Switch to turn off labels along the x- (horizontal) axis\
            but leave those along the y- (vertical) axis.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMatSelPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MAT_SEL_PY_METADATA)
    cargs = []
    cargs.append("fat_mat_sel.py")
    cargs.extend([
        "--Pars",
        parameters
    ])
    if matr_in is not None:
        cargs.extend([
            "--matr_in",
            matr_in
        ])
    if list_match is not None:
        cargs.extend([
            "--list_match",
            execution.input_file(list_match)
        ])
    if out_ind_matr:
        cargs.append("--out_ind_matr")
    if out_ind_1ddset:
        cargs.append("--Out_ind_1ddset")
    if hold_image:
        cargs.append("--Hold_image")
    if extern_labs_no:
        cargs.append("--ExternLabsNo")
    if type_file is not None:
        cargs.extend([
            "--type_file",
            type_file
        ])
    if dpi_file is not None:
        cargs.extend([
            "--dpi_file",
            str(dpi_file)
        ])
    if xlen_file is not None:
        cargs.extend([
            "--xlen_file",
            str(xlen_file)
        ])
    if ylen_file is not None:
        cargs.extend([
            "--ylen_file",
            str(ylen_file)
        ])
    if tight_layout_on:
        cargs.append("--Tight_layout_on")
    if fig_off:
        cargs.append("--Fig_off")
    if size_font is not None:
        cargs.extend([
            "--Size_font",
            str(size_font)
        ])
    if lab_size_font is not None:
        cargs.extend([
            "--Lab_size_font",
            str(lab_size_font)
        ])
    if a_plotmin is not None:
        cargs.extend([
            "--A_plotmin",
            str(a_plotmin)
        ])
    if b_plotmax is not None:
        cargs.extend([
            "--B_plotmax",
            str(b_plotmax)
        ])
    if cbar_off:
        cargs.append("--Cbar_off")
    if map_of_colors is not None:
        cargs.extend([
            "--Map_of_colors",
            map_of_colors
        ])
    if cbar_int_num is not None:
        cargs.extend([
            "--cbar_int_num",
            str(cbar_int_num)
        ])
    if width_cbar_perc is not None:
        cargs.extend([
            "--width_cbar_perc",
            str(width_cbar_perc)
        ])
    if specifier is not None:
        cargs.extend([
            "--specifier",
            specifier
        ])
    if xtick_lab_off:
        cargs.append("--Xtick_lab_off")
    ret = FatMatSelPyOutputs(
        root=execution.output_file("."),
        individual_images=execution.output_file("individual_images/*"),
        matrix_grids=execution.output_file("matrix_grids/*"),
        v_1_d_dsets=execution.output_file("1D_dsets/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MAT_SEL_PY_METADATA",
    "FatMatSelPyOutputs",
    "fat_mat_sel_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LFCD_METADATA = Metadata(
    id="bf72e901409ebf787635076f27fc633055ebec14.boutiques",
    name="3dLFCD",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLfcdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_lfcd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    out_file_: OutputPathType
    """Output file."""


def v_3d_lfcd(
    in_file: InputPathType,
    autoclip: bool = False,
    automask: bool = False,
    mask: InputPathType | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    polort: int | None = None,
    thresh: float | None = None,
    runner: Runner | None = None,
) -> V3dLfcdOutputs:
    """
    Performs degree centrality on a dataset using a given maskfile via the 3dLFCD
    command.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3dlfcd.
        autoclip: Clip off low-intensity regions in the dataset.
        automask: Mask the dataset to target brain-only voxels.
        mask: Mask file to mask input data.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        polort: No description provided.
        thresh: Threshold to exclude connections where corr <= thresh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLfcdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LFCD_METADATA)
    cargs = []
    cargs.append("3dLFCD")
    cargs.append(execution.input_file(in_file))
    if autoclip:
        cargs.append("-autoclip")
    if automask:
        cargs.append("-automask")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if thresh is not None:
        cargs.extend([
            "-thresh",
            str(thresh)
        ])
    ret = V3dLfcdOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_afni"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLfcdOutputs",
    "V_3D_LFCD_METADATA",
    "v_3d_lfcd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEG_OVERLAP_METADATA = Metadata(
    id="e61800f776c2289b9b4a7391243b109288f38e81.boutiques",
    name="mri_seg_overlap",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegOverlapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_seg_overlap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    overlap_report: OutputPathType | None
    """Detailed overlap report saved to a JSON file."""


def mri_seg_overlap(
    vol1: InputPathType,
    vol2: InputPathType,
    out_file: str | None = None,
    measures: list[str] | None = None,
    labels: list[str] | None = None,
    label_names: list[str] | None = None,
    label_file: InputPathType | None = None,
    no_names_flag: bool = False,
    seg_flag: bool = False,
    quiet_flag: bool = False,
    runner: Runner | None = None,
) -> MriSegOverlapOutputs:
    """
    Compute the structural overlap between two segmentation volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        vol1: First segmentation volume input.
        vol2: Second segmentation volume input.
        out_file: Save detailed overlap report to a JSON file.
        measures: List of measures to compute. Options include: dice, jaccard,\
            voldiff.
        labels: Space-separated list of label values to include.
        label_names: Custom label names corresponding to the values specified\
            with the --labels flag.
        label_file: Text file specifying the label values to include. Must be\
            in the format of a freesurfer lookup-table.
        no_names_flag: Do not report label names.
        seg_flag: Compute overlap between the major segmentation structures.
        quiet_flag: Quiet mode - do not print results to stdout.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegOverlapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEG_OVERLAP_METADATA)
    cargs = []
    cargs.append("mri_seg_overlap")
    cargs.append(execution.input_file(vol1))
    cargs.append(execution.input_file(vol2))
    if out_file is not None:
        cargs.extend([
            "-o",
            out_file
        ])
    if measures is not None:
        cargs.extend([
            "-m",
            *measures
        ])
    if labels is not None:
        cargs.extend([
            "-l",
            *labels
        ])
    if label_names is not None:
        cargs.extend([
            "-n",
            *label_names
        ])
    if label_file is not None:
        cargs.extend([
            "-f",
            execution.input_file(label_file)
        ])
    if no_names_flag:
        cargs.append("-x")
    if seg_flag:
        cargs.append("-s")
    if quiet_flag:
        cargs.append("-q")
    ret = MriSegOverlapOutputs(
        root=execution.output_file("."),
        overlap_report=execution.output_file(out_file) if (out_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEG_OVERLAP_METADATA",
    "MriSegOverlapOutputs",
    "mri_seg_overlap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SIMULATE_ATROPHY_METADATA = Metadata(
    id="9e01b9ada9b0b4569fbd5e16610a336ed0c78036.boutiques",
    name="mris_simulate_atrophy",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSimulateAtrophyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_simulate_atrophy(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Atrophy simulation output volume."""


def mris_simulate_atrophy(
    subject: str,
    hemi: str,
    label: str,
    atrophy_fraction: float,
    output_volume: InputPathType,
    atrophy_percent: float | None = None,
    noise_level: float | None = None,
    runner: Runner | None = None,
) -> MrisSimulateAtrophyOutputs:
    """
    Simulate atrophy on brain structures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        hemi: Hemisphere (e.g. lh or rh).
        label: Label of the brain region.
        atrophy_fraction: Target atrophy fraction.
        output_volume: Output volume file.
        atrophy_percent: Percentage atrophy to simulate of structure.
        noise_level: Gaussian noise level to add.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSimulateAtrophyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SIMULATE_ATROPHY_METADATA)
    cargs = []
    cargs.append("mris_simulate_atrophy")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(label)
    cargs.append(str(atrophy_fraction))
    cargs.append(execution.input_file(output_volume))
    if atrophy_percent is not None:
        cargs.extend([
            "-a",
            str(atrophy_percent)
        ])
    if noise_level is not None:
        cargs.extend([
            "-n",
            str(noise_level)
        ])
    ret = MrisSimulateAtrophyOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output_volume).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SIMULATE_ATROPHY_METADATA",
    "MrisSimulateAtrophyOutputs",
    "mris_simulate_atrophy",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SMOOTH_DISPLACEMENT_FIELD_METADATA = Metadata(
    id="74242e4a08e876a4821008fd823b0b832ab0e019.boutiques",
    name="SmoothDisplacementField",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SmoothDisplacementFieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `smooth_displacement_field(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    smoothed_field: OutputPathType
    """The output file containing the smoothed displacement field."""
    confidence_image_out: OutputPathType | None
    """The output file containing confidence information from the smoothing
    process."""


def smooth_displacement_field(
    image_dimension: int,
    input_field: InputPathType,
    output_field: InputPathType,
    variance_or_mesh_size_base_level: float,
    number_of_levels: int | None = 1,
    spline_order: int | None = 3,
    estimate_inverse: typing.Literal[0, 1] | None = 0,
    confidence_image: InputPathType | None = None,
    runner: Runner | None = None,
) -> SmoothDisplacementFieldOutputs:
    """
    SmoothDisplacementField applies smoothing to a displacement field over a
    specified number of levels with optional parameters for spline order, inverse
    estimation, and confidence image output.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the input displacement field.
        input_field: The input displacement field file.
        output_field: The output file for the smoothed displacement field.
        variance_or_mesh_size_base_level: The variance for Gaussian smoothing\
            or mesh size at the base level for B-spline smoothing.
        number_of_levels: The number of levels for multi-resolution smoothing.
        spline_order: The order of the spline for B-spline smoothing.
        estimate_inverse: Estimate the inverse of the displacement field if set\
            to 1.
        confidence_image: Optional confidence image output of the smoothing\
            process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SmoothDisplacementFieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SMOOTH_DISPLACEMENT_FIELD_METADATA)
    cargs = []
    cargs.append("SmoothDisplacementField")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_field))
    cargs.append(execution.input_file(output_field))
    cargs.append(str(variance_or_mesh_size_base_level))
    if number_of_levels is not None:
        cargs.append(str(number_of_levels))
    if spline_order is not None:
        cargs.append(str(spline_order))
    if estimate_inverse is not None:
        cargs.append(str(estimate_inverse))
    if confidence_image is not None:
        cargs.append(execution.input_file(confidence_image))
    ret = SmoothDisplacementFieldOutputs(
        root=execution.output_file("."),
        smoothed_field=execution.output_file(pathlib.Path(output_field).name),
        confidence_image_out=execution.output_file(pathlib.Path(confidence_image).name) if (confidence_image is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SMOOTH_DISPLACEMENT_FIELD_METADATA",
    "SmoothDisplacementFieldOutputs",
    "smooth_displacement_field",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REGISTER_LABEL_MAP_METADATA = Metadata(
    id="da7f5799fccbaa00ae28b92114de5d6ef1a4db4f.boutiques",
    name="mris_register_label_map",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRegisterLabelMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_register_label_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_register_label_map(
    subjects_list: str,
    target_subject: str,
    prior: str,
    label: str,
    template_volume: InputPathType,
    debug: bool = False,
    check_opts: bool = False,
    help_: bool = False,
    subjects_dir: str | None = None,
    version: bool = False,
    vno: float | None = None,
    runner: Runner | None = None,
) -> MrisRegisterLabelMapOutputs:
    """
    Tool for registering label maps in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects_list: List of training subjects.
        target_subject: Name of target subject.
        prior: Name of prior surface overlay.
        label: Name of label for each subject.
        template_volume: Template volume file.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        help_: Print out information on how to use this program.
        subjects_dir: SUBJECTS_DIR.
        version: Print out version and exit.
        vno: Debug this vertex.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRegisterLabelMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REGISTER_LABEL_MAP_METADATA)
    cargs = []
    cargs.append("mris_register_label_map")
    cargs.extend([
        "--subjects",
        subjects_list
    ])
    cargs.extend([
        "--trgsubject",
        target_subject
    ])
    cargs.extend([
        "--prior",
        prior
    ])
    cargs.extend([
        "--label",
        label
    ])
    cargs.extend([
        "--temp-vol",
        execution.input_file(template_volume)
    ])
    if debug:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    if help_:
        cargs.append("--help")
    if subjects_dir is not None:
        cargs.extend([
            "--sdir",
            subjects_dir
        ])
    if version:
        cargs.append("--version")
    if vno is not None:
        cargs.extend([
            "--v",
            str(vno)
        ])
    ret = MrisRegisterLabelMapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REGISTER_LABEL_MAP_METADATA",
    "MrisRegisterLabelMapOutputs",
    "mris_register_label_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_COLORED_FA_METADATA = Metadata(
    id="9942a5ec79bb71bf37d6af7b5ec7bc808a0b17b5.boutiques",
    name="dmri_coloredFA",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriColoredFaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_colored_fa(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_colored_fa: OutputPathType
    """The output colored FA image."""


def dmri_colored_fa(
    input_volume: InputPathType,
    output_volume: str = "colored_FA",
    runner: Runner | None = None,
) -> DmriColoredFaOutputs:
    """
    Tool for generating colored FA maps from diffusion MRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input diffusion MRI volume.
        output_volume: Output colored FA image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriColoredFaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_COLORED_FA_METADATA)
    cargs = []
    cargs.append("dmri_coloredFA")
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_volume)
    ret = DmriColoredFaOutputs(
        root=execution.output_file("."),
        output_colored_fa=execution.output_file(output_volume + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_COLORED_FA_METADATA",
    "DmriColoredFaOutputs",
    "dmri_colored_fa",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_NEIGHBORING_REGIONS_METADATA = Metadata(
    id="0178eb527b86ea0845721b0e3a911c76330df23a.boutiques",
    name="dmri_neighboringRegions",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriNeighboringRegionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_neighboring_regions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_file: OutputPathType
    """Resulting output file from dmri_neighboringRegions"""


def dmri_neighboring_regions(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> DmriNeighboringRegionsOutputs:
    """
    A tool for diffusion MRI analysis involving neighboring regions.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input image file (e.g. img.nii.gz).
        output_file: Output result file (e.g. result.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriNeighboringRegionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_NEIGHBORING_REGIONS_METADATA)
    cargs = []
    cargs.append("dmri_neighboringRegions")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = DmriNeighboringRegionsOutputs(
        root=execution.output_file("."),
        result_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_NEIGHBORING_REGIONS_METADATA",
    "DmriNeighboringRegionsOutputs",
    "dmri_neighboring_regions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SUB_MGH_METADATA = Metadata(
    id="b225e0584e88c37a1a9ef9c5295eb2118fddc2cc.boutiques",
    name="fsl_sub_mgh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FslSubMghOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sub_mgh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_sub_mgh(
    estimated_time: int | None = None,
    queue_name: str | None = "long.q",
    architecture: str | None = None,
    job_priority: int | None = 0,
    email_address: str | None = "root@fmrib.ox.ac.uk",
    hold_job: str | None = None,
    task_file: InputPathType | None = None,
    job_name: str | None = None,
    log_dir: str | None = None,
    mail_options: str | None = None,
    flags_in_scripts: bool = False,
    verbose: bool = False,
    shell_path: str | None = None,
    runner: Runner | None = None,
) -> FslSubMghOutputs:
    """
    Wrapper for job control system such as SGE, modified for compatibility with the
    PBS queueing system.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        estimated_time: Estimated job length in minutes, used to auto-set queue\
            name.
        queue_name: Queue name. Possible values are 'verylong.q', 'long.q' and\
            'short.q'. Default is 'long.q'.
        architecture: Architecture [e.g., darwin or lx24-amd64].
        job_priority: Job priority [0:-1024]. Default is 0.
        email_address: Email address to send notifications. Default is\
            root@fmrib.ox.ac.uk.
        hold_job: Job ID to place a hold on this task until completion.
        task_file: Task file of commands to execute in parallel.
        job_name: Specify job name as it will appear on the queue.
        log_dir: Output directory for log files.
        mail_options: Change the SGE mail options.
        flags_in_scripts: Use flags embedded in scripts to set SGE queuing\
            options.
        verbose: Verbose mode.
        shell_path: Change the PBS shell option.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSubMghOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SUB_MGH_METADATA)
    cargs = []
    cargs.append("fsl_sub_mgh")
    if estimated_time is not None:
        cargs.extend([
            "-T",
            str(estimated_time)
        ])
    if queue_name is not None:
        cargs.extend([
            "-q",
            queue_name
        ])
    if architecture is not None:
        cargs.extend([
            "-a",
            architecture
        ])
    if job_priority is not None:
        cargs.extend([
            "-p",
            str(job_priority)
        ])
    if email_address is not None:
        cargs.extend([
            "-M",
            email_address
        ])
    if hold_job is not None:
        cargs.extend([
            "-j",
            hold_job
        ])
    if task_file is not None:
        cargs.extend([
            "-t",
            execution.input_file(task_file)
        ])
    if job_name is not None:
        cargs.extend([
            "-N",
            job_name
        ])
    if log_dir is not None:
        cargs.extend([
            "-l",
            log_dir
        ])
    if mail_options is not None:
        cargs.extend([
            "-m",
            mail_options
        ])
    if flags_in_scripts:
        cargs.append("-F")
    if verbose:
        cargs.append("-v")
    if shell_path is not None:
        cargs.extend([
            "-s",
            shell_path
        ])
    cargs.append("<COMMAND>")
    ret = FslSubMghOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SUB_MGH_METADATA",
    "FslSubMghOutputs",
    "fsl_sub_mgh",
]
